class SVC {

    private enum Kernel { LINEAR, POLY, RBF, SIGMOID }

    private int nClasses;
    private int nRows;
    private int[] classes;
    private double[][] vectors;
    private double[][] coefficients;
    private double[] intercepts;
    private int[] weights;
    private Kernel kernel;
    private double gamma;
    private double coef0;
    private double degree;

    public SVC (int nClasses, int nRows, double[][] vectors, double[][] coefficients, double[] intercepts, int[] weights, String kernel, double gamma, double coef0, double degree) {
        this.nClasses = nClasses;
        this.classes = new int[nClasses];
        for (int i = 0; i < nClasses; i++) {
            this.classes[i] = i;
        }
        this.nRows = nRows;

        this.vectors = vectors;
        this.coefficients = coefficients;
        this.intercepts = intercepts;
        this.weights = weights;

        this.kernel = Kernel.valueOf(kernel.toUpperCase());
        this.gamma = gamma;
        this.coef0 = coef0;
        this.degree = degree;
    }

    public int predict(double[] features) {

        double[] kernels = new double[vectors.length];
        double kernel;
        switch (this.kernel) {
            case LINEAR:
                // <x,x'>
                for (int i = 0; i < this.vectors.length; i++) {
                    kernel = 0.;
                    for (int j = 0; j < this.vectors[i].length; j++) {
                        kernel += this.vectors[i][j] * features[j];
                    }
                    kernels[i] = kernel;
                }
                break;
            case POLY:
                // (y<x,x'>+r)^d
                for (int i = 0; i < this.vectors.length; i++) {
                    kernel = 0.;
                    for (int j = 0; j < this.vectors[i].length; j++) {
                        kernel += this.vectors[i][j] * features[j];
                    }
                    kernels[i] = Math.pow((this.gamma * kernel) + this.coef0, this.degree);
                }
                break;
            case RBF:
                // exp(-y|x-x'|^2)
                for (int i = 0; i < this.vectors.length; i++) {
                    kernel = 0.;
                    for (int j = 0; j < this.vectors[i].length; j++) {
                        kernel += Math.pow(this.vectors[i][j] - features[j], 2);
                    }
                    kernels[i] = Math.exp(-this.gamma * kernel);
                }
                break;
            case SIGMOID:
                // tanh(y<x,x'>+r)
                for (int i = 0; i < this.vectors.length; i++) {
                    kernel = 0.;
                    for (int j = 0; j < this.vectors[i].length; j++) {
                        kernel += this.vectors[i][j] * features[j];
                    }
                    kernels[i] = Math.tanh((this.gamma * kernel) + this.coef0);
                }
                break;
        }

        int[] starts = new int[this.nRows];
        for (int i = 0; i < this.nRows; i++) {
            if (i != 0) {
                int start = 0;
                for (int j = 0; j < i; j++) {
                    start += this.weights[j];
                }
                starts[i] = start;
            } else {
                starts[0] = 0;
            }
        }

        int[] ends = new int[this.nRows];
        for (int i = 0; i < this.nRows; i++) {
            ends[i] = this.weights[i] + starts[i];
        }

        if (this.nClasses == 2) {

            for (int i = 0; i < kernels.length; i++) {
                kernels[i] = -kernels[i];
            }

            double decision = 0.;
            for (int k = starts[1]; k < ends[1]; k++) {
                decision += kernels[k] * this.coefficients[0][k];
            }
            for (int k = starts[0]; k < ends[0]; k++) {
                decision += kernels[k] * this.coefficients[0][k];
            }
            decision += this.intercepts[0];

            if (decision > 0) {
                return 0;
            }
            return 1;

        }

        double[] decisions = new double[this.intercepts.length];
        for (int i = 0, d = 0, l = this.nRows; i < l; i++) {
            for (int j = i + 1; j < l; j++) {
                double tmp = 0.;
                for (int k = starts[j]; k < ends[j]; k++) {
                    tmp += this.coefficients[i][k] * kernels[k];
                }
                for (int k = starts[i]; k < ends[i]; k++) {
                    tmp += this.coefficients[j - 1][k] * kernels[k];
                }
                decisions[d] = tmp + this.intercepts[d];
                d++;
            }
        }

        int[] votes = new int[this.intercepts.length];
        for (int i = 0, d = 0, l = this.nRows; i < l; i++) {
            for (int j = i + 1; j < l; j++) {
                votes[d] = decisions[d] > 0 ? i : j;
                d++;
            }
        }

        int[] amounts = new int[this.nClasses];
        for (int i = 0, l = votes.length; i < l; i++) {
            amounts[votes[i]] += 1;
        }

        int classVal = -1, classIdx = -1;
        for (int i = 0, l = amounts.length; i < l; i++) {
            if (amounts[i] > classVal) {
                classVal = amounts[i];
                classIdx= i;
            }
        }
        return this.classes[classIdx];

    }

//    public static void main(String[] args) {
//        if (args.length == 0) {
//
//            // Features:
////            double[] features = new double[args.length];
////            for (int i = 0, l = args.length; i < l; i++) {
////                features[i] = Double.parseDouble(args[i]);
////            }
//
//            // Parameters:
//            double[][] vectors = {{-0.0908542, 0.201572, 0.040528600000000005, 0.22475355709910352, 0.4580697330057946, 0.1559578804030114, -0.488485, 0.051242, -0.031671, 1.020401}, {0.2208684, 0.41270439999999997, 1.014771, 0.4945928253622367, 0.9714336936419283, 0.8921022153792131, -0.49417, 0.888051, -0.745532, 1.751919}, {-0.016621399999999998, 0.6481058, 0.08115479999999997, 0.19091193285072572, 0.6027066628565674, 1.1453139110517692, -0.259348, 0.270311, 0.23877, 1.652501}, {-0.16305719999999999, 0.3969481999999999, 0.4117076, 0.4266084534092122, 1.0706829679399499, 0.7311607860896945, -0.906775, 0.152003, -0.589713, 2.215143}, {0.0403628, 0.4290804, 0.419074, 0.27291137715511243, 0.8793025593200556, 0.6709502545021502, -0.232451, 0.494745, -0.033878, 1.995904}, {0.088287, 0.12487380000000003, 0.4706008, 0.17979164169810563, 1.6412705522322333, 0.7111376299600521, -0.052791, 0.392426, -2.466655, 1.84081}, {-0.14819339999999998, 0.3184920000000001, 0.4462918, 0.3784382854340982, 1.9203603699635388, 0.779966067093114, -0.800851, 0.137645, -1.998058, 3.336679}, {-0.137762, -0.16152740000000004, 0.576026, 0.3284603365834298, 1.913585488230484, 0.8471697363093773, -0.666844, 0.216769, -2.555211, 2.353976}, {0.080052, 0.4986198, 0.03208519999999998, 0.1333387824734424, 0.6089345610360771, 0.402661240480382, -0.019743, 0.286877, 0.037304, 1.188135}, {-0.432638, 0.5107188, 0.33248779999999994, 0.25766783894386197, 0.8477713525200649, 1.0456395466001658, -0.819693, -0.222851, -0.519751, 1.720371}, {-0.034318400000000006, 0.4279756, 0.276349, 0.21964531781328736, 0.8007485967051707, 0.6187482860444948, -0.275509, 0.272296, 0.003736, 1.855455}, {-0.047116000000000005, 0.7109706, 0.2665832, 0.11759734757425441, 1.421110101349927, 0.43545228283843, -0.198435, 0.12836, -0.033787, 3.249583}, {-0.22287300000000002, 0.30581579999999997, 0.421066, 0.2829406863407948, 0.5895821668285092, 0.9695764627475236, -0.68959, 0.005488, -0.421385, 1.161304}, {0.01210239999999999, 0.309579, 0.43697379999999997, 0.35228062874546484, 0.7593124525891828, 1.0156907653376592, -0.390448, 0.579997, -0.618913, 1.457308}, {-0.3542952, 0.2868564, 0.40888159999999996, 1.026917760938382, 1.0254761809019748, 0.9380817542977264, -1.631995, 1.007612, -1.218451, 1.396688}, {-0.4518420000000001, 0.18985920000000003, 0.3637822, 0.47498617779362806, 0.3092572358518067, 0.9023909051180092, -1.209229, 0.014693, -0.177692, 0.570899}, {-0.06564620000000002, 0.0910274, 0.0800704, 0.41451018092406366, 0.1350294202083383, 0.3318757607935536, -0.706724, 0.454001, 0.001126, 0.322854}, {-0.4844018, 0.47413819999999995, 0.051496600000000003, 0.7915917361668829, 0.6923583851728814, 0.2812621880280035, -1.45707, 0.297816, -0.056691, 1.349668}, {-0.6155682, 0.2573302, 0.16004739999999998, 0.8170589525243573, 0.4760277955431804, 0.6784981702099866, -1.878706, 0.07732, -0.002404, 1.103303}, {-0.6743857999999999, 0.17515739999999996, 0.5403214000000001, 0.8632783693118344, 0.9115476987751655, 0.9197192104834496, -1.688613, 0.078131, -1.240301, 1.132742}, {-0.49328939999999993, 0.223649, 0.4610704, 0.6140129724666248, 0.4595056257027763, 0.9336525602130056, -1.505431, 0.025067, -0.308077, 0.89894}, {-0.3844526, 0.29015979999999997, 0.2303408, 0.5626748001677345, 0.4820762451850329, 0.5951241260243111, -1.332555, 0.04428, -0.063875, 1.124062}, {-0.4953468, 0.42183539999999997, 0.0799952, 0.5925505752285622, 0.5283298043422309, 0.21280022023649317, -1.270216, -0.006765, -0.031319, 1.151285}, {-0.7852134, 0.5568066, 0.3302276, 1.3446981190318517, 0.761597139880265, 0.8654798849772881, -3.075728, 0.177154, -0.045163, 1.597106}, {-0.5116468000000001, 0.03792520000000001, 0.4386138, 0.8909083232940974, 0.9549074749331476, 0.6193095146808257, -1.751633, 0.513175, -1.394213, 1.285612}, {-0.4445335999999999, 0.06177299999999997, 0.2711964, 0.9208302746040119, 0.7223617011196676, 0.7657160737282456, -1.718999, 0.572686, -0.959466, 1.066056}, {-0.3708182, 0.141646, 0.1247328, 0.4482594780941057, 0.18536242717983598, 0.3923210635483392, -1.116646, 0.021719, -0.03089, 0.416946}, {-0.6867672, 0.406515, 0.08235680000000001, 0.9194342447770258, 0.5337614174493132, 0.34469797011180675, -1.727541, 0.090888, 0.003985, 1.237663}, {-0.6481804, 0.2014514, 0.3570712, 0.6358896977285448, 0.5772416551482575, 0.6982928754596455, -1.36752, 0.08312, -0.491043, 1.071383}, {-0.40831420000000007, -0.04699, 0.18099279999999998, 0.8031566887035181, 0.22613470793644216, 0.36266728595739095, -1.732143, 0.302021, -0.434483, 0.121278}, {-0.681373, 0.0315982, -0.0092748, 1.02206031886895, 0.24690858082638603, 0.04623474704916206, -2.331297, 0.041699, -0.274799, 0.416119}, {-0.46917220000000004, -0.0362438, 0.0882676, 0.7500603826720885, 0.16127416540072376, 0.38447136889019445, -1.300038, 0.157262, -0.213196, 0.209011}, {-0.317373, -0.2993466, 0.030779800000000003, 0.44040802262674555, 0.5851329990098832, 0.02336722565261011, -0.82942, 0.03897, -1.344476, -0.002547}, {-0.274795, 0.0108618, -0.031532399999999995, 0.3097268416847336, 0.047201600764169, 0.1272279656415994, -0.606385, 0.019216, -0.026777, 0.083304}, {-0.2142508, -0.12821860000000002, 0.0895804, 0.7196194341526637, 0.2711501610110162, 0.26533258508200613, -1.214245, 0.595397, -0.596763, 0.104819}, {-0.4544874, -0.036049, 0.13489, 0.7490514361743125, 0.2156792873887059, 0.2777136960495467, -1.737443, 0.084787, -0.377481, 0.220788}, {-0.428246, -0.042401999999999995, 0.04338860000000001, 0.8056716266789465, 0.3870668128747283, 0.2969901377062882, -1.477032, 0.461909, -0.584463, 0.495173}, {-0.3250094, -0.0731066, 0.1752616, 0.744576582143704, 0.20461270272224058, 0.37219129536744944, -1.537794, 0.382204, -0.418664, 0.12335}, {-0.5320853999999999, -0.010120600000000002, 0.03533139999999999, 0.7361462164035756, 0.1522965579758781, 0.3583139383994153, -1.76393, -0.012296, -0.243432, 0.184074}, {-0.4396756, -0.0708008, 0.367446, 0.7736004261453713, 0.1532713988541241, 0.5354616889180774, -1.553839, 0.457548, -0.323368, 0.094162}, {-0.816324, 0.08627660000000001, 0.0777272, 1.1504728207865234, 0.25469629949667505, 0.15954437507069938, -2.132338, 0.026379, -0.06224, 0.539213}, {-0.405568, -0.29919780000000007, -0.18995480000000003, 0.5992051430737223, 0.35916070681548673, 0.18496376322863894, -1.420558, 0.044735, -0.851462, -0.010352}, {-0.2090834, -0.26549659999999997, -0.0835804, 0.4962775867524142, 0.3420463068113731, 0.22394810384841396, -0.93524, 0.3347, -0.766157, 0.029943}, {-0.3017274, -0.15655439999999998, 0.14676720000000001, 0.8435333898582795, 0.28911021354372796, 0.28770902561911404, -1.777546, 0.33093, -0.666051, 0.052244}, {-0.003953999999999969, -0.19815159999999998, -0.07632639999999999, 0.4920070539199616, 0.4222880022079718, 0.19647954365353154, -0.613462, 0.720601, -0.837464, 0.244951}, {-0.401419, -0.2267248, -0.161411, 0.6128424590622782, 0.7764795878944276, 0.46913013137881054, -1.446533, 0.059137, -0.987338, 0.873013}, {-0.4315042, -0.3798958, -0.19280579999999997, 0.7627950045865534, 0.48476844129254126, 0.6602247532921649, -1.751936, 0.022172, -1.060092, 0.013276}, {-0.42456820000000006, -0.4017868, -0.2184444, 0.8561999655978153, 0.5560511930026767, 0.30612495268648066, -1.952325, 0.0206, -1.175643, 0.030658}, {-0.49925700000000006, -0.3130112, -0.10751840000000001, 0.6571245603106766, 0.4591486090087826, 0.2552275357035365, -1.286615, 0.039659, -0.954974, 0.042155}, {-0.13802820000000002, -0.37069359999999996, 0.03312719999999998, 0.487051194850911, 0.5360489632583015, 0.49399964753246534, -0.93278, 0.268929, -1.154756, 0.028409}, {-0.06237280000000002, -0.3543196, -0.06397800000000001, 0.3664392664729041, 0.3689998483296436, 0.34152191808067023, -0.585005, 0.285969, -0.802119, -0.023572}, {-0.20514079999999998, -0.18650280000000002, -0.2273818, 0.3268014784195445, 0.41908644106580206, 0.3211560020008968, -0.664733, 0.133545, -0.808455, 0.288033}, {0.08900619999999998, -0.24907939999999998, -0.04862919999999997, 0.8437478755162586, 0.6899866355345587, 1.3405785373247254, -0.846496, 1.402378, -1.013914, 0.710979}, {0.045955199999999995, -0.1613416, -0.2522142, 0.5498282736534199, 0.22088918548856123, 0.627991882944119, -0.664517, 0.880687, -0.475151, 0.124728}, {0.2414554, 0.1477452, 0.5881732000000001, 0.6800335522610631, 0.6044393978139578, 0.6607536334487311, -0.752034, 0.979844, -0.717128, 0.93757}, {0.36800160000000004, 0.3345724, 0.49306, 0.7607048139941011, 0.6591814156063565, 0.6237992706199648, -0.532113, 1.434751, -0.33734, 1.341999}, {0.48562220000000006, 0.1842352, 0.47436860000000003, 0.6442803208287523, 0.39161351340473427, 0.6775721914064213, 0.048098, 1.611574, -0.281752, 0.658154}, {0.3890668, 0.42956120000000003, 0.46043599999999996, 0.7125153436808923, 0.8724733367912741, 0.7338212372526431, 0.006492, 1.659177, -0.058042, 1.985044}, {0.3001246, 0.14918979999999998, 0.3877394, 0.6548902911494413, 0.7479737833037331, 0.49722926632872283, -0.31779, 1.402842, -0.884079, 1.179876}, {0.457375, 0.23245259999999995, 0.7744481999999999, 0.7228001675020559, 0.7330737983077147, 0.9606590391170012, -0.17306, 1.674318, -0.693625, 1.170108}, {0.30878659999999997, -0.0021377999999999454, 0.8661552, 0.5810048920274252, 1.1622425047156466, 0.6749851934199742, -0.25984, 1.094172, -1.424051, 1.663518}, {0.269012, 0.19945080000000004, 0.34229180000000003, 0.2475648811978387, 0.7296387871681439, 0.5022357399316579, 0.074224, 0.583885, -0.865303, 1.123331}, {0.318056, 0.2571572, 0.416605, 0.5807105124530638, 0.7071044141972245, 0.6406054705713963, -0.429946, 1.086735, -0.667307, 1.023044}, {0.2918754, 0.3015188, 0.6294700000000001, 0.32166530705812835, 0.7372107855655666, 1.080210072455585, -0.057133, 0.706207, -0.239803, 1.590026}, {0.43923560000000006, 0.29217459999999995, 0.5278664, 0.6017140008133431, 0.32938908177761445, 0.5816892853433867, -0.114494, 1.349248, 0.001513, 0.757276}, {0.23442120000000002, 0.07390180000000006, 0.65415, 0.6897023898666005, 1.0201720250581272, 0.8279699630626706, -0.852606, 1.013905, -1.461048, 1.381804}, {0.181829, 0.2887404, 0.044573800000000004, 0.25401367076793324, 0.4791899537493457, 0.19516333345098408, -0.036572, 0.584221, -0.007417, 1.115374}, {0.3995794, 0.30066699999999996, 0.499437, 0.3461135981210504, 0.7313228914545885, 0.46621441314967943, 0.021057, 0.804793, -0.598054, 1.239561}, {0.31106999999999996, 0.2960814, 0.33961040000000003, 0.328367755419895, 0.3521778429122139, 0.6152816607711464, -0.033804, 0.695108, -0.002327, 0.817518}, {0.5664382, -0.012232799999999999, 0.11796419999999999, 0.677068671045781, 0.14574138905506562, 0.3849197830038098, -0.024763, 1.612277, -0.16447, 0.211848}, {0.4833302, -0.0450096, 0.16508479999999998, 0.6386005096562326, 0.060373120060172474, 0.37167683215758823, -0.153563, 1.367913, -0.135123, 0.007979}, {0.400551, -0.047166200000000005, 0.20347980000000004, 0.7271344388371382, 0.21772830575099786, 0.3400087195178971, 0.007568, 1.690058, -0.4176, 0.143611}, {0.4070792000000001, -0.113246, 0.415755, 1.0111346084442467, 0.2702020749809298, 0.4796724932993344, -0.483341, 2.143488, -0.549529, 0.176971}, {0.34373899999999996, 0.044013, 0.13118760000000002, 0.5981146991706523, 0.06494717249811573, 0.3688974370835341, -0.079558, 1.336868, -0.019188, 0.147163}, {0.3428708, -0.0437172, 0.401802, 0.6432428070982993, 0.052899331713170065, 0.6880694235242546, -0.179097, 1.40271, -0.101149, 0.00618}, {0.2241576, -0.07411039999999999, 0.2769162, 0.8596676464589673, 0.1315671662357292, 0.3346340544216921, -0.869944, 1.537732, -0.212211, 0.080188}, {0.24179659999999997, -0.1160052, 0.306246, 1.032330986746402, 0.14256285503840052, 0.544956434993202, -0.826009, 1.928371, -0.337223, 0.034688}, {0.4678243999999999, -0.03469500000000001, 0.041699999999999994, 0.6354221284565874, 0.3928924809785751, 0.16037487228521805, 0.018336, 1.56018, -0.653811, 0.423524}, {0.44608299999999995, -0.029677799999999997, 0.39495519999999995, 0.6443913041479532, 0.1229165763666561, 0.6132253789702445, -0.094368, 1.352885, -0.211968, 0.120259}, {0.7385648, -0.0314096, 0.2996122, 1.2738909964008693, 0.31652165289644874, 0.40894833797644903, -0.049426, 2.995255, -0.541188, 0.329026}, {0.2817214, -0.08863240000000001, 0.2682048, 0.8576422726436123, 0.14975513850048686, 0.3289280626454666, -0.704539, 1.641676, -0.27682, 0.133763}, {0.354059, -0.1135512, 0.23596180000000003, 0.7322183867293282, 0.3794240683018145, 0.33010068129239, -0.441323, 1.280935, -0.548023, 0.430664}, {0.27736399999999994, 0.0068736000000000005, 0.161353, 0.5363044512098515, 0.058127223908423495, 0.3005390382387952, -0.134163, 1.211458, -0.045008, 0.100531}, {0.3762852, -0.20186639999999997, -0.0889018, 0.42058571923235816, 0.3655143561473338, 0.34515412014229235, -0.123559, 0.969901, -0.810012, 0.103601}, {0.7629968, -0.2406768, -0.080283, 1.0950552767192623, 0.8322499164744325, 0.45235974310718674, -0.061691, 2.147613, -1.117441, 0.939112}, {0.39238039999999996, -0.28967960000000004, 0.006468999999999997, 0.5631696499277993, 0.35220790162885335, 0.1309473076030966, -0.123078, 1.123461, -0.856415, -0.011447}, {0.38592339999999997, -0.2688146, -0.09305899999999998, 0.43980408548500316, 0.2782738010418875, 0.3124898648564462, -0.174803, 0.871027, -0.662148, -0.011544}, {0.800202, -0.37782479999999996, 0.17570460000000004, 1.1027107262015727, 0.6026040731663702, 0.21320486425337487, -0.216178, 2.398518, -1.408361, 0.006082}, {0.2632522, -0.24547320000000003, -0.0538296, 0.3244931473894326, 0.4469512653569738, 0.114441538434696, -0.091553, 0.701402, -1.003929, 0.102927}, {0.22830320000000004, -0.24837479999999998, -0.0022402000000000047, 0.581488033622103, 0.44993348012589596, 0.1973245131900748, -0.457742, 1.144136, -0.877225, 0.286627}, {0.3427076, -0.20061140000000002, -0.075841, 0.5055868582818387, 0.46822415898242586, 0.3741373115782493, -0.108994, 0.927154, -0.970469, 0.258589}, {0.321487, -0.29292179999999995, -0.0355286, 0.5596899475901813, 0.3708254362563334, 0.13774072516616137, -0.134754, 1.180685, -0.734575, -0.017307}, {0.6570572, -0.2943494, 0.0697538, 1.4017942045167329, 0.5790822549537328, 0.10564383084307384, -0.074634, 3.155373, -1.328017, 0.006331}, {0.3564324, -0.3267172, -0.05036740000000001, 0.44059207090607067, 0.37668169690827824, 0.3125383588270406, -0.08676, 0.934717, -0.736284, 0.007663}, {0.3777352, -0.37250520000000004, -0.0379664, 0.4130891083909137, 0.5337246323828422, 0.23933429015458693, -0.18109, 0.853298, -1.234342, -0.014167}, {0.2967778, -0.12869820000000004, -0.02890999999999999, 0.4144159053236253, 0.4636545500005365, 0.3091826938955349, -0.085543, 0.790423, -0.683444, 0.505062}, {0.3534428, -0.22299200000000002, 0.06302940000000001, 0.5437726403072336, 0.49489223304725644, 0.513668295352458, -0.211938, 1.177594, -1.068295, 0.14634}, {0.224247, -0.25521340000000003, -0.044603199999999996, 0.7584890171825165, 0.4715306522717267, 0.16716193913298563, -0.37025, 1.545305, -1.08573, 0.014218}};
//            double[][] coefficients = {{1.0, 0.3286713190027083, 0.0, 0.8425855736317368, 0.0, 0.0, 0.0, 0.6913237629794858, 0.7752598700925979, 1.0, 0.0, 0.0, 1.0, 0.3633467566646609, -1.0, -0.6296283101270835, -1.0, -0.44167612800533035, -0.0, -0.761524506750176, -0.0, -1.0, -1.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.1683583374885999, -0.0, -0.0, -0.0, -0.9599069836721147, -1.0, -0.0, -0.0, -1.0, -0.0, -0.0, -0.0, -0.5136459454173509, -0.0, -0.0, -0.008734924531785872, -0.7173694582229896, -1.0, -0.0, -0.0, -0.0, -0.0, -0.027638712868024717, -1.0, -1.0, -0.3265468890210429, -0.6824192992495619, -0.0, -0.0, -0.929893390017017, -0.0, -0.0, -1.0, -1.0, -0.0, -1.0, -0.0, -1.0, -1.0, -1.0, -1.0, -0.0, -0.0, -0.0, -0.0, -0.18467095271870984, -0.0, -0.0, -0.0, -0.2636368219075677, -0.0, -0.4894226183352871, -0.0, -1.0, -1.0, -0.0, -0.46440929517387425, -0.0, -0.0, -0.0, -1.0, -0.0, -0.4508355502704309, -0.0, -0.5591203922372651, -0.0, -0.0, -1.0, -0.0, -0.0}, {1.0, 0.0, 0.0, 0.0, 0.0, 0.3650566891998653, 0.27536223569990004, 0.2300909463946772, 0.5266868011562739, 0.0, 0.0, 0.07635625663874925, 1.0, 0.0, 0.0, 1.0, 1.0, 0.0, 1.0, 0.0, 0.3819940703379247, 0.0, 0.8283675921063894, 0.30509768552266847, 0.5437287371854381, 1.0, 1.0, 0.8767196627270412, 0.0, -0.0, -1.0, -1.0, -0.6269446250432932, -1.0, -0.3398395632540843, -0.1671755201656068, -1.0, -0.0, -0.8019480394164775, -1.0, -1.0, -0.0, -0.0, -1.0, -0.08823197344406836, -1.0, -0.9991030894962099, -0.0, -0.3222660454067134, -0.0, -0.0, -1.0, -1.0, -1.0, -1.0, -0.2154273037986155, -0.0, -0.0, -0.0, -0.0, -0.166476627500222, -0.0, -0.0, -0.0, -0.0, -1.0, -1.0, -0.0, -1.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.0, -0.0, -0.0, -0.0, -0.21770480422254435, -0.0, -1.0, -1.0, -0.0, -0.0, -0.0, -0.677891726933386, -0.0, -0.0, -1.0, -0.0, -0.0, -0.6240207312152961, -0.0, -0.0, -1.0, -0.0, -0.0}, {1.0, 0.0, 0.0, 0.0, 0.0, 0.4634357230549584, 0.15720504160362947, 0.2913753574893525, 0.16827386249590265, 0.0, 0.0, 0.0, 1.0, 1.0, 0.5223198906050048, 1.0, 1.0, 0.0, 0.0, 0.34085021850092195, 0.0, 0.0, 0.2483015352611172, 0.10561041072067842, 1.0, 1.0, 1.0, 0.0, 0.19251905325926918, 1.0, 0.18043736441574407, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 0.9331708928366487, 1.0, 0.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -0.0, -0.07095890919178031, -1.0, -0.042649348060612526, -1.0, -1.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.6296567504477555, -1.0, -0.0, -0.7356802630926819, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.0, -0.0, -0.0, -0.0, -0.030102822214721783, -0.2018996102056544, -1.0, -1.0, -0.0, -0.0, -0.0, -0.7108295609337628, -0.0, -1.0, -1.0, -0.0, -0.0, -0.34948184112656705, -0.0, -0.0, -0.7449836957904526, -0.0, -0.0}, {1.0, 1.0, 0.12331095571964425, 0.0, 1.0, 1.0, 0.0, 0.48900173354693444, 1.0, 0.0, 1.0, 0.0, 1.0, 1.0, 1.0, 0.03854473550470952, 1.0, 0.15005503180422508, 0.0, 0.0, 0.0, 0.7238539774128858, 0.0, 0.0, 0.7429549501958153, 0.0, 0.7264952363812016, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5040051687617177, 1.0, 0.8613318447787195, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5894204326253448, 1.0, 1.0, -1.0, -0.0, -0.40773605994939693, -0.0, -0.0, -0.0, -0.0, -0.16092681328631445, -0.5289465219507296, -0.0, -0.0, -1.0, -1.0, -0.0, -0.49181103743890386, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0015337864591192776, -1.0, -0.4369054355644796, -1.0, -0.0, -0.0, -0.013307126568869667, -1.0, -1.0, -0.0, -0.0, -0.0, -1.0, -0.0, -1.0, -1.0, -1.0, -0.0, -0.3599031580699907, -0.09344548746330267, -1.0, -1.0, -0.29330839211328286, -0.0}, {1.0, 0.6755308650836439, 0.0, 0.0, 0.0, 0.22233277317224226, 0.21667383066285653, 0.08457914679660464, 0.7299946594340524, 0.0, 0.0, 0.0, 0.0, 0.008619117812164926, 0.9979439424173336, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.21976086180521068, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.2824549578418352, 1.0, 1.0, 0.0, 0.2642583414105781, 0.0, 0.0, 0.6852891331679629, 0.0, 0.0, 0.0, 0.45174634859246854, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 1.0, 1.0, 1.0, 0.0, 1.0, 0.0, 1.0, 0.22653249494767708, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.8953340853838181, 0.0, 1.0, -0.0, -0.0, -0.0, -0.0, -1.0, -0.4759585802286025, -0.05494199741787081, -0.0, -1.0, -1.0, -0.590966002685022, -0.0, -1.0, -1.0, -0.4377669829507595, -1.0, -0.0, -0.0, -0.0, -0.0, -1.0, -1.0, -0.0, -0.3715621031745709, -0.0, -0.0, -1.0, -1.0, -0.0}, {1.0, 0.22837090229701956, 0.0, 0.0, 0.0, 0.7136739837474382, 0.19153163984769012, 0.0, 0.773843433155317, 0.0, 0.0, 0.0, 0.0, 0.5669452786341055, 1.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.25021275973155105, 0.05169969841713086, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 1.0, 1.0, 0.0, 0.8052950978507827, 0.0, 0.0, 0.0, 0.0, 0.0, 0.7466570376465762, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 0.0, 1.0, 0.0, 1.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.5872590783423293, 0.46595372537211627, 0.7561162824108849, 0.0, 0.0, 0.20786361465114178, 1.0, 1.0, 1.0, 0.0, 0.0, 0.8966925839974177, 0.0, 1.0, 1.0, 1.0, 0.016768651720385865, 1.0, 1.0, -0.0, -1.0, -1.0, -1.0, -0.6422793611329571, -0.0, -1.0, -0.0, -1.0, -1.0, -0.8598725632913393, -0.0, -1.0, -0.0, -0.6191729259446489}};
//            double[] intercepts = {0.08989983286102736, 0.1877135651956848, 0.2314890303386506, 0.2900807770204332, 0.32768150056389905, 0.2361812837986856, 0.13026512329594037, 0.03391757423784676, 0.1722461057527737, 0.23437989465284062, 0.10975230737775948, -0.3265934926893508, -0.08538273434849114, 0.13450184758513756, -0.10051661388833175, -0.07370782439171789, 0.09298884726902468, -0.003261829032549491, 0.019311591472517334, 0.06905718026684746, -0.525449084266981};
//            int[] weights = {14, 15, 12, 13, 15, 14, 15};
//
//            double [] features = new double[]{0.6602676000000001, 0.8472924, 0.41202200000000005, 0.65123137148424, 1.17610527329744, 0.8217283040588,-0.056378,1.677724,0.023149,2.729929};
//            // Prediction:
//            SVC clf = new SVC(7, 7, vectors, coefficients, intercepts, weights, "rbf", 0.2, 0.0, 3);
//            int estimation = clf.predict(features);
//            System.out.println(estimation);
//
//        }
//    }
}